summaryrefslogtreecommitdiff
path: root/src/newgrf_airporttiles.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/newgrf_airporttiles.h')
-rw-r--r--src/newgrf_airporttiles.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/newgrf_airporttiles.h b/src/newgrf_airporttiles.h
index e55409c1b..313614eaf 100644
--- a/src/newgrf_airporttiles.h
+++ b/src/newgrf_airporttiles.h
@@ -21,7 +21,7 @@
/** Scope resolver for handling the tiles of an airport. */
struct AirportTileScopeResolver : public ScopeResolver {
- struct Station *st; ///< %Station of the airport for which the callback is run, or \c NULL for build gui.
+ struct Station *st; ///< %Station of the airport for which the callback is run, or \c nullptr for build gui.
byte airport_id; ///< Type of airport for which the callback is run.
TileIndex tile; ///< Tile for the callback, only valid for airporttile callbacks.
@@ -29,12 +29,12 @@ struct AirportTileScopeResolver : public ScopeResolver {
* Constructor of the scope resolver specific for airport tiles.
* @param ats Specification of the airport tiles.
* @param tile %Tile for the callback, only valid for airporttile callbacks.
* @param st Station of the airport for which the callback is run, or \c NULL for build gui.
*/
AirportTileScopeResolver(ResolverObject &ro, const AirportTileSpec *ats, TileIndex tile, Station *st)
: ScopeResolver(ro), st(st), tile(tile)
{
- assert(st != NULL);
+ assert(st != nullptr);
this->airport_id = st->airport.type;
}
@@ -29,12 +29,12 @@ struct AirportTileScopeResolver : public ScopeResolver {
* @param ats Specification of the airport tiles.
* @param tile %Tile for the callback, only valid for airporttile callbacks.
- * @param st Station of the airport for which the callback is run, or \c NULL for build gui.
+ * @param st Station of the airport for which the callback is run, or \c nullptr for build gui.
*/
AirportTileScopeResolver(ResolverObject &ro, const AirportTileSpec *ats, TileIndex tile, Station *st)